@@ -845,37 +845,41 @@ void initiatePipeline(AlevinOpts<ProtocolT>& aopt,
   spp::sparse_hash_map<uint32_t, uint32_t> txpToGeneMap;
   spp::sparse_hash_map<std::string, uint32_t> geneIdxMap;
 
-  auto txpInfoFile = sopt.indexDirectory / "ctable.bin";
-  if(!boost::filesystem::exists(txpInfoFile)){
-    aopt.jointLog->error("Index Directory or the ctable.bin: {} doesn't exist.",
-                         txpInfoFile.string());
-    aopt.jointLog->flush();
-    exit(1);
+  // if we are running in alignment-only `align` or `justAlign` mode
+  // then we don't even need the txp-gene map.
+  if (!aopt.just_align) {
+    auto txpInfoFile = sopt.indexDirectory / "ctable.bin";
+    if (!boost::filesystem::exists(txpInfoFile)) {
+      aopt.jointLog->error(
+          "Index Directory or the ctable.bin: {} doesn't exist.",
+          txpInfoFile.string());
+      aopt.jointLog->flush();
+      exit(1);
+    }
+
+    auto txpLengthFile = sopt.indexDirectory / "reflengths.bin";
+    if (!boost::filesystem::exists(txpLengthFile)) {
+      aopt.jointLog->error(
+          "Index Directory or the reflengths.bin: {} doesn't exist.",
+          txpLengthFile.string());
+      aopt.jointLog->flush();
+      exit(1);
+    }
+
+    auto headerFile = sopt.indexDirectory / "info.json";
+    if (!boost::filesystem::exists(headerFile)) {
+      aopt.jointLog->error(
+          "Index Directory or the info.json: {} doesn't exist.",
+          headerFile.string());
+      aopt.jointLog->flush();
+      exit(1);
+    }
+
+    aut::getTxpToGeneMap(txpToGeneMap, geneIdxMap, aopt.geneMapFile.string(),
+                         txpInfoFile.string(), txpLengthFile.string(),
+                         headerFile.string(), aopt.jointLog, noTgMap);
   }
-
-  auto txpLengthFile = sopt.indexDirectory / "reflengths.bin";
-  if(!boost::filesystem::exists(txpLengthFile)){
-    aopt.jointLog->error("Index Directory or the reflengths.bin: {} doesn't exist.",
-                         txpLengthFile.string());
-    aopt.jointLog->flush();
-    exit(1);
-  }
-
-  auto headerFile = sopt.indexDirectory / "info.json";
-  if(!boost::filesystem::exists(headerFile)){
-    aopt.jointLog->error("Index Directory or the info.json: {} doesn't exist.",
-                         headerFile.string());
-    aopt.jointLog->flush();
-    exit(1);
-  }
-
-  aut::getTxpToGeneMap(txpToGeneMap, geneIdxMap,
-                       aopt.geneMapFile.string(),
-                       txpInfoFile.string(),
-                       txpLengthFile.string(),
-                       headerFile.string(),
-                       aopt.jointLog, noTgMap);
-
+  
   // If we're supposed to be quiet, set the global logger level to >= warn
   if (aopt.quiet) {
     spdlog::set_level(spdlog::level::warn); //Set global log level to warn
@@ -886,14 +890,24 @@ void initiatePipeline(AlevinOpts<ProtocolT>& aopt,
 
   if (aopt.just_align) {
     // if we are just aligning 
+
+    // write out the cmd_info.json to make sure we have that
+    boost::filesystem::path outputDirectory = vm["output"].as<std::string>();
+    bool isWriteOk = aut::writeCmdInfo(outputDirectory / "cmd_info.json", orderedOptions);
+    if(!isWriteOk){
+      fmt::print(stderr, "Writing cmd_info.json in output directory failed.\nExiting now.");
+      exit(1);
+    }
+
+    // do the actual mapping
     auto rc = alevin_sc_align(aopt, sopt, orderedOptions);
+
     if (rc == 0) {
       aopt.jointLog->info("sc-align successful.");
-      std::exit(0);
     } else {
       aopt.jointLog->error("sc-align exited with return code {}", rc);
-      std::exit(rc);
     }
+    std::exit(rc);
   }
 
   /*
@@ -942,7 +956,7 @@ void initiatePipeline(AlevinOpts<ProtocolT>& aopt,
     // Write out information about the command / run
     bool isWriteOk = aut::writeCmdInfo(cmdInfoPath / "cmd_info.json", orderedOptions);
     if(!isWriteOk){
-      fmt::print(stderr, "writing in output directory failed\n Exiting Now");
+      fmt::print(stderr, "Writing cmd_info.json in output directory failed.\nExiting now.");
       exit(1);
     }
   }
@@ -1006,7 +1020,6 @@ salmon-based processing of single-cell RNA-seq data.
     green[3] = '0' + static_cast<char>(fmt::GREEN);
     red[3] = '0' + static_cast<char>(fmt::RED);
 
-
     bool noTgMap {false};
     bool dropseq = vm["dropseq"].as<bool>();
     bool indrop = vm["indrop"].as<bool>();
@@ -1034,7 +1047,7 @@ salmon-based processing of single-cell RNA-seq data.
     if (celseq) validate_num_protocols += 1;
     if (celseq2) validate_num_protocols += 1;
     if (quartzseq2) validate_num_protocols += 1;
-    if (custom and !noTgMap) validate_num_protocols += 1;
+    if (custom) validate_num_protocols += 1;
 
     if ( validate_num_protocols != 1 ) {
       fmt::print(stderr, "ERROR: Please specify one and only one scRNA protocol;");
