@@ -367,9 +367,9 @@ std::vector<std::string> getLibTypeStrings(const ExpT& experiment) {
   return libStrings;
 }
 
-template <typename AlnT, typename EQBuilderT>
+template <typename AlnT, typename EQBuilderT, typename AlignModelT>
 std::vector<std::string>
-getLibTypeStrings(const AlignmentLibrary<AlnT, EQBuilderT>& experiment) {
+getLibTypeStrings(const AlignmentLibrary<AlnT, EQBuilderT, AlignModelT>& experiment) {
   std::vector<std::string> libStrings;
   libStrings.push_back(experiment.format().toString());
   return libStrings;
@@ -891,6 +891,84 @@ bool GZipWriter::writeMeta(const SalmonOpts& opts, const ExpT& experiment, const
   return true;
 }
 
+/**
+ * Write the ``main'' metadata to file when executing in alevin-fry mode.  Currently this 
+ * writes a stripped down version of meta_info.json:
+ *   -- A json file with information about the run
+ */
+template <typename ExpT>
+bool GZipWriter::writeMetaFryMode(const SalmonOpts& opts, const ExpT& experiment, const MappingStatistics& mstats) {
+
+  namespace bfs = boost::filesystem;
+  using salmon::utils::DuplicateTargetStatus;
+
+  bfs::path auxDir = path_ / opts.auxDir;
+  bool auxSuccess = boost::filesystem::create_directories(auxDir);
+  auto numBootstraps = 0;
+  auto numSamples = 0;
+
+  bfs::path info = auxDir / "meta_info.json";
+  {
+    std::ofstream os(info.string());
+    cereal::JSONOutputArchive oa(os);
+
+    std::string sampType = "none";
+    auto& transcripts = experiment.transcripts();
+    oa(cereal::make_nvp("salmon_version", std::string(salmon::version)));
+    oa(cereal::make_nvp("samp_type", sampType));
+
+    std::string optType = "rad_mode";
+    oa(cereal::make_nvp("opt_type", optType));
+
+    std::vector<std::string> errors;
+    oa(cereal::make_nvp("quant_errors", errors));
+
+    auto libStrings = getLibTypeStrings(experiment);
+    oa(cereal::make_nvp("num_libraries", libStrings.size()));
+    oa(cereal::make_nvp("library_types", libStrings));
+
+    auto has_dups = experiment.index_retains_duplicates();
+    switch(has_dups) {
+      case DuplicateTargetStatus::RETAINED_DUPLICATES:
+        oa(cereal::make_nvp("keep_duplicates", true));
+        break;
+      case DuplicateTargetStatus::REMOVED_DUPLICATES:
+        oa(cereal::make_nvp("keep_duplicates", false));
+        break;
+      case DuplicateTargetStatus::UNKNOWN:
+      default:
+        break;
+    }
+
+    auto numValidTargets = transcripts.size();
+    auto numDecoys = experiment.getNumDecoys();
+    oa(cereal::make_nvp("num_valid_targets", numValidTargets));
+    oa(cereal::make_nvp("num_decoy_targets", numDecoys));
+    
+    oa(cereal::make_nvp("length_classes", experiment.getLengthQuantiles()));
+    oa(cereal::make_nvp("index_seq_hash", experiment.getIndexSeqHash256()));
+    oa(cereal::make_nvp("index_name_hash", experiment.getIndexNameHash256()));
+    oa(cereal::make_nvp("index_seq_hash512", experiment.getIndexSeqHash512()));
+    oa(cereal::make_nvp("index_name_hash512", experiment.getIndexNameHash512()));
+    oa(cereal::make_nvp("index_decoy_seq_hash", experiment.getIndexDecoySeqHash256()));
+    oa(cereal::make_nvp("index_decoy_name_hash", experiment.getIndexDecoyNameHash256()));
+    oa(cereal::make_nvp("num_bootstraps", numSamples));
+    oa(cereal::make_nvp("num_processed", experiment.numObservedFragments()));
+    oa(cereal::make_nvp("num_mapped", experiment.numMappedFragments()));
+    //oa(cereal::make_nvp("num_decoy_fragments", mstats.numDecoyFragments.load()));
+    //oa(cereal::make_nvp("num_dovetail_fragments", mstats.numDovetails.load()));
+    oa(cereal::make_nvp("num_fragments_filtered_vm", mstats.numFragmentsFiltered.load()));
+    oa(cereal::make_nvp("num_alignments_below_threshold_for_mapped_fragments_vm",
+                        mstats.numMappingsFiltered.load()));
+    //oa(cereal::make_nvp("percent_mapped",
+    //                    experiment.effectiveMappingRate() * 100.0));
+    oa(cereal::make_nvp("call", std::string("quant")));
+    oa(cereal::make_nvp("start_time", opts.runStartTime));
+    oa(cereal::make_nvp("end_time", opts.runStopTime));
+  }
+  return true;
+}
+
 bool GZipWriter::writeAbundances(
                                  std::vector<double>& alphas,
                                  std::vector<Transcript>& transcripts) {
@@ -1669,8 +1747,8 @@ void GZipWriter::writeMtx(std::shared_ptr<spdlog::logger>& jointLog,
 
 using SCExpT = ReadExperiment<EquivalenceClassBuilder<SCTGValue>>;
 using BulkExpT = ReadExperiment<EquivalenceClassBuilder<TGValue>>;
-template <typename FragT>
-using BulkAlignLibT = AlignmentLibrary<FragT, EquivalenceClassBuilder<TGValue>>;
+template <typename FragT, typename AlignModelT>
+using BulkAlignLibT = AlignmentLibrary<FragT, EquivalenceClassBuilder<TGValue>, AlignModelT>;
 
 template bool
 GZipWriter::writeBootstrap<double>(const std::vector<double>& abund,
@@ -1682,11 +1760,14 @@ template bool GZipWriter::writeBootstrap<int>(const std::vector<int>& abund,
 template bool GZipWriter::writeEquivCounts<BulkExpT>(const SalmonOpts& sopt,
                                              BulkExpT& readExp);
 
-template bool GZipWriter::writeEquivCounts<BulkAlignLibT<UnpairedRead>>(
-    const SalmonOpts& sopt, BulkAlignLibT<UnpairedRead>& readExp);
+template bool GZipWriter::writeEquivCounts<BulkAlignLibT<UnpairedRead,AlignmentModel>>(
+   const SalmonOpts& sopt, BulkAlignLibT<UnpairedRead,AlignmentModel>& readExp);
 
-template bool GZipWriter::writeEquivCounts<BulkAlignLibT<ReadPair>>(
-    const SalmonOpts& sopt, BulkAlignLibT<ReadPair>& readExp);
+template bool GZipWriter::writeEquivCounts<BulkAlignLibT<UnpairedRead,ONTAlignmentModel>>(
+   const SalmonOpts& sopt, BulkAlignLibT<UnpairedRead,ONTAlignmentModel>& readExp);
+
+template bool GZipWriter::writeEquivCounts<BulkAlignLibT<ReadPair,AlignmentModel>>(
+   const SalmonOpts& sopt, BulkAlignLibT<ReadPair,AlignmentModel>& readExp);
 
 template bool GZipWriter::writeBFH<SCExpT>(boost::filesystem::path& outDir,
                                            SCExpT& experiment, size_t umiLength,
@@ -1696,22 +1777,27 @@ template bool GZipWriter::writeAbundances<BulkExpT>(const SalmonOpts& sopt,
                                                     BulkExpT& readExp,
                                                     bool explicitSum);
 
-template bool GZipWriter::writeAbundances<BulkAlignLibT<UnpairedRead>>(const SalmonOpts& sopt,
-                                                                       BulkAlignLibT<UnpairedRead>& readExp,
-                                                                       bool explicitSum);
-template bool GZipWriter::writeAbundances<BulkAlignLibT<ReadPair>>(const SalmonOpts& sopt,
-                                                                   BulkAlignLibT<ReadPair>& readExp,
-                                                                   bool explicitSum);
+template bool GZipWriter::writeAbundances<BulkAlignLibT<UnpairedRead,AlignmentModel>>(const SalmonOpts& sopt,
+                                                                                      BulkAlignLibT<UnpairedRead,AlignmentModel>& readExp,
+                                                                                      bool explicitSum);
+template bool GZipWriter::writeAbundances<BulkAlignLibT<UnpairedRead,ONTAlignmentModel>>(const SalmonOpts& sopt,
+                                                                                         BulkAlignLibT<UnpairedRead,ONTAlignmentModel>& readExp,
+                                                                                         bool explicitSum);
+template bool GZipWriter::writeAbundances<BulkAlignLibT<ReadPair,AlignmentModel>>(const SalmonOpts& sopt,
+                                                                                  BulkAlignLibT<ReadPair,AlignmentModel>& readExp,
+                                                                                  bool explicitSum);
 
 template bool GZipWriter::writeEmptyAbundances<BulkExpT>(const SalmonOpts& sopt,
                                                  BulkExpT& readExp);
 template bool GZipWriter::writeEmptyAbundances<SCExpT>(const SalmonOpts& sopt,
                                                                SCExpT& readExp);
 
-template bool GZipWriter::writeEmptyAbundances<BulkAlignLibT<UnpairedRead>>(
-    const SalmonOpts& sopt, BulkAlignLibT<UnpairedRead>& readExp);
-template bool GZipWriter::writeEmptyAbundances<BulkAlignLibT<ReadPair>>(
-    const SalmonOpts& sopt, BulkAlignLibT<ReadPair>& readExp);
+template bool GZipWriter::writeEmptyAbundances<BulkAlignLibT<UnpairedRead,AlignmentModel>>(
+    const SalmonOpts& sopt, BulkAlignLibT<UnpairedRead,AlignmentModel>& readExp);
+template bool GZipWriter::writeEmptyAbundances<BulkAlignLibT<UnpairedRead,ONTAlignmentModel>>(
+    const SalmonOpts& sopt, BulkAlignLibT<UnpairedRead,ONTAlignmentModel>& readExp);
+template bool GZipWriter::writeEmptyAbundances<BulkAlignLibT<ReadPair,AlignmentModel>>(
+    const SalmonOpts& sopt, BulkAlignLibT<ReadPair,AlignmentModel>& readExp);
 
 template bool
 GZipWriter::writeMeta<BulkExpT>(const SalmonOpts& opts,
@@ -1723,11 +1809,19 @@ GZipWriter::writeMeta<SCExpT>(const SalmonOpts& opts,
                               const MappingStatistics& mstats);
 
 template bool
-GZipWriter::writeMeta<BulkAlignLibT<UnpairedRead>>(const SalmonOpts& opts, const BulkAlignLibT<UnpairedRead>& experiment,
-                                                   const MappingStatistics& mstats);
+GZipWriter::writeMetaFryMode<SCExpT>(const SalmonOpts& opts,
+                              const SCExpT& experiment,
+                              const MappingStatistics& mstats);
 
 template bool
-GZipWriter::writeMeta<BulkAlignLibT<ReadPair>>(const SalmonOpts& opts, const BulkAlignLibT<ReadPair>& experiment,
+GZipWriter::writeMeta<BulkAlignLibT<UnpairedRead,AlignmentModel>>(const SalmonOpts& opts, const BulkAlignLibT<UnpairedRead,AlignmentModel>& experiment,
+                                                   const MappingStatistics& mstats);
+template bool
+GZipWriter::writeMeta<BulkAlignLibT<UnpairedRead,ONTAlignmentModel>>(const SalmonOpts& opts, const BulkAlignLibT<UnpairedRead,ONTAlignmentModel>& experiment,
+                                                                     const MappingStatistics& mstats);
+
+template bool
+GZipWriter::writeMeta<BulkAlignLibT<ReadPair,AlignmentModel>>(const SalmonOpts& opts, const BulkAlignLibT<ReadPair,AlignmentModel>& experiment,
                                                const MappingStatistics& mstats);
 
 template bool
@@ -1739,19 +1833,26 @@ GZipWriter::writeEmptyMeta<SCExpT>(const SalmonOpts& opts,
                                            const SCExpT& experiment,
                                            std::vector<std::string>& errors);
 
-template bool GZipWriter::writeEmptyMeta<BulkAlignLibT<UnpairedRead>>(
-    const SalmonOpts& opts, const BulkAlignLibT<UnpairedRead>& experiment,
+template bool GZipWriter::writeEmptyMeta<BulkAlignLibT<UnpairedRead,AlignmentModel>>(
+    const SalmonOpts& opts, const BulkAlignLibT<UnpairedRead,AlignmentModel>& experiment,
     std::vector<std::string>& errors);
 
-template bool GZipWriter::writeEmptyMeta<BulkAlignLibT<ReadPair>>(
-    const SalmonOpts& opts, const BulkAlignLibT<ReadPair>& experiment,
+template bool GZipWriter::writeEmptyMeta<BulkAlignLibT<UnpairedRead,ONTAlignmentModel>>(
+    const SalmonOpts& opts, const BulkAlignLibT<UnpairedRead,ONTAlignmentModel>& experiment,
+    std::vector<std::string>& errors);
+
+template bool GZipWriter::writeEmptyMeta<BulkAlignLibT<ReadPair,AlignmentModel>>(
+    const SalmonOpts& opts, const BulkAlignLibT<ReadPair,AlignmentModel>& experiment,
     std::vector<std::string>& errors);
 
 template std::vector<std::string>
-getLibTypeStrings(const BulkAlignLibT<UnpairedRead>& experiment);
+getLibTypeStrings(const BulkAlignLibT<UnpairedRead,AlignmentModel>& experiment);
 
 template std::vector<std::string>
-getLibTypeStrings(const BulkAlignLibT<ReadPair>& experiment);
+getLibTypeStrings(const BulkAlignLibT<UnpairedRead,ONTAlignmentModel>& experiment);
+
+template std::vector<std::string>
+getLibTypeStrings(const BulkAlignLibT<ReadPair,AlignmentModel>& experiment);
 
 namespace apt = alevin::protocols;
 
