@@ -323,7 +323,9 @@ namespace salmon {
     ("eqclasses,e", po::value<string>(),
      "input salmon weighted equivalence class file.")
     ("targets,t", po::value<std::string>(),
-     "FASTA format file containing target transcripts.");
+     "FASTA format file containing target transcripts.")
+      ("ont", po::bool_switch(&(sopt.oxfordNanoporeModel))->default_value(false)->notifier([&sopt](const bool& v) { if(v) sopt.noLengthCorrection = true; }),
+     "use alignment model for Oxford Nanopore long reads");
 
     return alignin;
   }
